dream/servers/mist/internal
Internal bridge between Mist and Dream for WebSockets/streaming
This module uses the Erlang process dictionary to stash per-request data (the current Mist request and an optional upgrade response). It is used by the Mist handler and WebSocket modules to coordinate HTTP → WebSocket upgrades and should not be used directly by application code.
Values
pub fn get(key: atom.Atom) -> dynamic.Dynamic
pub fn put(
key: atom.Atom,
value: dynamic.Dynamic,
) -> dynamic.Dynamic
pub const request_key: String
pub const response_key: String
pub fn to_dynamic(a: a) -> dynamic.Dynamic
pub fn unsafe_coerce(a: a) -> b